diff --git a/gnu/packages/guile-xyz.scm b/gnu/packages/guile-xyz.scm
index a85c7e0fc4..3c22f96e8c 100644
--- a/gnu/packages/guile-xyz.scm
+++ b/gnu/packages/guile-xyz.scm
@@ -63,64 +63,67 @@
 (define-module (gnu packages guile-xyz)
   #:use-module ((guix licenses) #:prefix license:)
   #:use-module (gnu packages)
-  #:use-module (gnu packages admin)
-  #:use-module (gnu packages algebra)
-  #:use-module (gnu packages aspell)
-  #:use-module (gnu packages autotools)
-  #:use-module (gnu packages avahi)
-  #:use-module (gnu packages base)
-  #:use-module (gnu packages bash)
-  #:use-module (gnu packages compression)
-  #:use-module (gnu packages crypto)
-  #:use-module (gnu packages databases)
-  #:use-module (gnu packages disk)
-  #:use-module (gnu packages emacs)
-  #:use-module (gnu packages emacs-xyz)
-  #:use-module (gnu packages gawk)
-  #:use-module (gnu packages gettext)
-  #:use-module (gnu packages gl)
-  #:use-module (gnu packages glib)
-  #:use-module (gnu packages gnome)
-  #:use-module (gnu packages gnupg)
-  #:use-module (gnu packages gperf)
-  #:use-module (gnu packages gstreamer)
-  #:use-module (gnu packages gtk)
-  #:use-module (gnu packages guile)
-  #:use-module (gnu packages haskell-xyz)         ;pandoc
-  #:use-module (gnu packages hurd)
-  #:use-module (gnu packages image)
-  #:use-module (gnu packages imagemagick)
-  #:use-module (gnu packages libffi)
-  #:use-module (gnu packages libunistring)
-  #:use-module (gnu packages linux)
-  #:use-module (gnu packages man)
-  #:use-module (gnu packages maths)
-  #:use-module (gnu packages mes)
-  #:use-module (gnu packages multiprecision)
-  #:use-module (gnu packages ncurses)
-  #:use-module (gnu packages networking)
-  #:use-module (gnu packages noweb)
-  #:use-module (gnu packages nss)
-  #:use-module (gnu packages package-management)
-  #:use-module (gnu packages password-utils)
-  #:use-module (gnu packages pcre)
-  #:use-module (gnu packages perl)
-  #:use-module (gnu packages pkg-config)
-  #:use-module (gnu packages python)
-  #:use-module (gnu packages readline)
-  #:use-module (gnu packages sdl)
-  #:use-module (gnu packages search)
-  #:use-module (gnu packages serialization)
-  #:use-module (gnu packages slang)
-  #:use-module (gnu packages sqlite)
-  #:use-module (gnu packages swig)
-  #:use-module (gnu packages tex)
-  #:use-module (gnu packages texinfo)
-  #:use-module (gnu packages tls)
-  #:use-module (gnu packages version-control)
-  #:use-module (gnu packages webkit)
-  #:use-module (gnu packages xdisorg)
-  #:use-module (gnu packages xorg)
+  #:autoload (gnu packages admin) (inetutils)
+  #:autoload (gnu packages algebra) (fftw)
+  #:autoload (gnu packages aspell) (aspell)
+  #:use-module (gnu packages autotools) ; required by "guix build -d guix"
+  #:use-module (gnu packages avahi) ; required by "guix build -d guix"
+  #:autoload (gnu packages base) (sed tzdata-for-tests which)
+  #:autoload (gnu packages bash) (bash bash-minimal)
+  #:autoload (gnu packages compression) (bzip2 lzip zip zlib)
+  #:autoload (gnu packages crypto) (libsodium)
+  #:autoload (gnu packages databases) (mariadb postgresql)
+  #:autoload (gnu packages disk) (parted)
+  #:autoload (gnu packages emacs) (emacs emacs-minimal)
+  #:autoload (gnu packages emacs-xyz)
+  (emacs-all-the-icons
+   emacs-all-the-icons-dired emacs-company emacs-dired-sidebar
+   emacs-doom-modeline emacs-f emacs-flycheck emacs-flycheck-guile emacs-geiser
+   emacs-geiser-guile emacs-ivy emacs-memoize emacs-modus-themes
+   emacs-paren-face)
+  #:use-module (gnu packages gettext) ; required by "guix build -d guix"
+  #:autoload (gnu packages gl) (freeglut guile-opengl mesa)
+  #:autoload (gnu packages glib) (dbus-glib glib gobject-introspection)
+  #:autoload (gnu packages gnome)
+  (clutter glib-networking gsettings-desktop-schemas librsvg vte)
+  #:autoload (gnu packages gnupg) (guile-gcrypt guile2.2-gcrypt)
+  #:autoload (gnu packages gperf) (gperf)
+  #:autoload (gnu packages gstreamer)
+  (gstreamer gst-plugins-base gst-plugins-good gst-plugins-bad gst-plugins-ugly)
+  #:autoload (gnu packages gtk)
+  (gtk+ gtksourceview guile-cairo guile-rsvg guile2.2-rsvg guile2.2-cairo)
+  #:use-module (gnu packages guile) ; required by "guix build -d guix"
+  #:autoload (gnu packages haskell-xyz) (pandoc)
+  #:autoload (gnu packages image) (freeimage vigra vigra-c)
+  #:autoload (gnu packages libffi) (libffi)
+  #:autoload (gnu packages linux) (eudev procps util-linux)
+  #:autoload (gnu packages man) (help2man)
+  #:autoload (gnu packages maths) (gsl)
+  #:autoload (gnu packages mes) (nyacc)
+  #:autoload (gnu packages ncurses) (ncurses ncurses/gpm)
+  #:autoload (gnu packages networking) (zeromq)
+  #:autoload (gnu packages nss) (nspr nss)
+  #:autoload (gnu packages package-management) (guix)
+  #:autoload (gnu packages password-utils) (shroud)
+  #:autoload (gnu packages pcre) (pcre2)
+  #:autoload (gnu packages perl) (perl perl-io-tty)
+  #:use-module (gnu packages pkg-config) ; required by "guix build -d guix"
+  #:autoload (gnu packages python) (python)
+  #:autoload (gnu packages sdl) (guile-sdl)
+  #:autoload (gnu packages search) (xapian)
+  #:autoload (gnu packages serialization) (libyaml)
+  #:autoload (gnu packages slang) (newt)
+  #:autoload (gnu packages sqlite) (sqlite)
+  #:autoload (gnu packages swig) (swig)
+  #:autoload (gnu packages tex)
+  (texlive-booktabs texlive-epsf texlive-fonts-iwona texlive-lm texlive-siunitx
+                    texlive-standalone texlive-updmap.cfg texlive-xcolor)
+  #:use-module (gnu packages texinfo) ; required by "guix build -d guix"
+  #:autoload (gnu packages tls) (openssl gnutls guile2.2-gnutls)
+  #:autoload (gnu packages webkit) (webkitgtk webkitgtk-with-libsoup2)
+  #:autoload (gnu packages xdisorg) (xosd)
+  #:autoload (gnu packages xorg)
+  (libx11 libxext libxinerama xorg-server xorg-server-for-tests)
   #:use-module (guix packages)
   #:use-module (guix download)
   #:use-module (guix gexp)
